[webbeans-commits] Webbeans SVN: r403 - in ri/trunk/webbeans-ri/src: test/java/org/jboss/webbeans/test/mock and 1 other directory.

webbeans-commits at lists.jboss.org webbeans-commits at lists.jboss.org
Thu Dec 4 12:58:45 EST 2008


Author: pete.muir at jboss.org
Date: 2008-12-04 12:58:45 -0500 (Thu, 04 Dec 2008)
New Revision: 403

Modified:
   ri/trunk/webbeans-ri/src/main/java/org/jboss/webbeans/bootstrap/spi/EjbDescriptor.java
   ri/trunk/webbeans-ri/src/main/java/org/jboss/webbeans/bootstrap/spi/WebBeanDiscovery.java
   ri/trunk/webbeans-ri/src/test/java/org/jboss/webbeans/test/mock/MockWebBeanDiscovery.java
Log:
Update SPI to support JNDI name per business interface

Modified: ri/trunk/webbeans-ri/src/main/java/org/jboss/webbeans/bootstrap/spi/EjbDescriptor.java
===================================================================
--- ri/trunk/webbeans-ri/src/main/java/org/jboss/webbeans/bootstrap/spi/WebBeanDiscovery.java	2008-12-04 14:15:21 UTC (rev 402)
+++ ri/trunk/webbeans-ri/src/main/java/org/jboss/webbeans/bootstrap/spi/WebBeanDiscovery.java	2008-12-04 17:58:45 UTC (rev 403)
@@ -48,6 +48,6 @@
     * 
     * @return The bean class to descriptor map 
     */
-   public Map<Class<?>, EjbDescriptor<?>> discoverEjbs();
+   public Map<String, EjbDescriptor<?>> discoverEjbs();
    
 }

Modified: ri/trunk/webbeans-ri/src/test/java/org/jboss/webbeans/test/mock/MockWebBeanDiscovery.java
===================================================================
--- ri/trunk/webbeans-ri/src/test/java/org/jboss/webbeans/test/mock/MockWebBeanDiscovery.java	2008-12-04 14:15:21 UTC (rev 402)
+++ ri/trunk/webbeans-ri/src/test/java/org/jboss/webbeans/test/mock/MockWebBeanDiscovery.java	2008-12-04 17:58:45 UTC (rev 403)
@@ -31,7 +31,7 @@
       return webBeanClasses;
    }
 
-   public Map<Class<?>, EjbDescriptor<?>> discoverEjbs()
+   public Map<String, EjbDescriptor<?>> discoverEjbs()
    {
       // TODO Auto-generated method stub
       return null;




More information about the weld-commits mailing list
--- ri/trunk/webbeans-ri/src/main/java/org/jboss/webbeans/bootstrap/spi/EjbDescriptor.java	2008-12-04 14:15:21 UTC (rev 402)
+++ ri/trunk/webbeans-ri/src/main/java/org/jboss/webbeans/bootstrap/spi/EjbDescriptor.java	2008-12-04 17:58:45 UTC (rev 403)
@@ -29,6 +29,24 @@
  */
 public interface EjbDescriptor<T>
 {
+   
+   public interface BusinessInterfaceDescriptor 
+   {
+   
+      /**
+       * Gets the business interface class
+       */
+      public Class<?> getInterface();
+   
+      /**
+       * Gets the JNDI name under which the EJB is registered
+       * 
+       * @return The JNDI name
+       */
+      public String getJndiName();
+      
+   }
+   
    /**
     * Gets the EJB type
     * 
@@ -37,18 +55,18 @@
    public Class<T> getType();
 
    /**
-    * Gets the JNDI name under which the EJB is registered
+    * Gets the local business interfaces of the EJB
     * 
-    * @return The JNDI name
+    * @return An iterator over the local business interfaces
     */
-   public String getJndiName();
-
+   public Iterator<BusinessInterfaceDescriptor> getLocalBusinessInterfaces();
+   
    /**
     * Gets the local interfaces of the EJB
     * 
-    * @return An iterator to the local interfaces 
+    * @return An iterator over the remote business interfaces
     */
-   public Iterator<Class<?>> getLocalInterfaces();
+   public Iterator<BusinessInterfaceDescriptor> getRemoteBusinessInterfaces();
 
    /**
     * Get the remove methods of the EJB
@@ -37,18 +55,18 @@
    /**
-    * Gets the local interfaces of the EJB
+    * Gets the remote business interfaces of the EJB
     * 

Modified: ri/trunk/webbeans-ri/src/main/java/org/jboss/webbeans/bootstrap/spi/WebBeanDiscovery.java
===================================================================